summaryrefslogtreecommitdiffstats
path: root/crypto
diff options
context:
space:
mode:
authorRichard Levitte <levitte@openssl.org>2006-12-25 09:43:46 +0000
committerRichard Levitte <levitte@openssl.org>2006-12-25 09:43:46 +0000
commitea46f5e0e5fbd21ac76876b57f5631c8b4263623 (patch)
tree5130131933c11a22f6056d947e612050dc9f54f5 /crypto
parent7f6c8482427b26e063e89f74d129f72fd1cdaa29 (diff)
Replace strdup() with BUF_strdup().
Diffstat (limited to 'crypto')
-rw-r--r--crypto/x509v3/v3_addr.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/crypto/x509v3/v3_addr.c b/crypto/x509v3/v3_addr.c
index 9580896096..b9be9995e1 100644
--- a/crypto/x509v3/v3_addr.c
+++ b/crypto/x509v3/v3_addr.c
@@ -66,6 +66,7 @@
#include <openssl/conf.h>
#include <openssl/asn1.h>
#include <openssl/asn1t.h>
+#include <openssl/buffer.h>
#include <openssl/x509v3.h>
#ifndef OPENSSL_NO_RFC3779
@@ -934,7 +935,7 @@ static void *v2i_IPAddrBlocks(struct v3_ext_method *method,
length = length_from_afi(afi);
/*
* Handle SAFI, if any, and strdup() so we can null-terminate
* the other input values.
*/
if (safi != NULL) {
@@ -946,9 +947,9 @@ static void *v2i_IPAddrBlocks(struct v3_ext_method *method,
goto err;
}
t += strspn(t, " \t");
- s = strdup(t);
+ s = BUF_strdup(t);
} else {
- s = strdup(val->value);
+ s = BUF_strdup(val->value);
}
if (s == NULL) {
X509V3err(X509V3_F_V2I_IPADDRBLOCKS, ERR_R_MALLOC_FAILURE);
@@ -934,7 +935,7 @@ static void *v2i_IPAddrBlocks(struct v3_ext_method *method,
length = length_from_afi(afi);
/*
- * Handle SAFI, if any, and strdup() so we can null-terminate
+ * Handle SAFI, if any, and BUF_strdup() so we can null-terminate
* the other input values.
*/